#
# spec file for package qdirstat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qdirstat
Version:        1.9
Release:        2.1
Summary:        Directory Statistics
License:        GPL-2.0-only
URL:            https://github.com/shundhammer/qdirstat
Source0:        %{name}-%{version}.tar.bz2
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  zlib-devel

%description

QDirStat is a graphical application to show where your disk space has
gone and to help you to clean it up.

It shows the total size of directories and of their files both in a
traditional tree view and in a colored [treemap
graphics](doc/Treemap.md) where a large file is shown as a large
rectangle, and small files are shown as small rectangles. Click on it,
and you will see where in the tree the file is, and you can instantly
move it to the trash if you like. The color corresponds to the file
type: Images, videos or whatever.

This is a Qt-only port of the old Qt3/KDE3-based KDirStat, now based
on the latest Qt 5. It does not need any KDE libs or
infrastructure. It runs on every X11-based desktop on Linux, BSD and
other Unix-like systems, and in a Docker container.

QDirStat has a number of new features compared to KDirStat.
To name a few:

- Multi-selection in both the tree and the treemap.

- Unlimited number of user-defined cleanup actions.

- Properly show errors of cleanup actions
  (and their output, if desired).

- Configurable file categories (MIME types), treemap colors,
  exclude rules, tree columns.

- Package manager support:

  - Show what software package a system file belongs to.

  - Packages view showing disk usage of installed software
    packages and their individual files.

  - Unpackaged files view showing what files in system directories
    do not belong to any installed software package.

- New views:

  - Disk usage per file type (by filename extension).

  - File size histogram view.

  - File age view.

  - Free, used and reserved disk size for each mounted filesystem
    (like df)


For more details and screenshots, see

    https://github.com/shundhammer/qdirstat

and the local documentation in

    /usr/share/doc/packages/qdirstat/README.md

%prep
%setup -q

%build
qmake-qt5
make

%install
make install INSTALL_ROOT=%{buildroot} %{?_smp_mflags}

# %suse_update_desktop_file -N "QDirStat" -G "Directory Statistics" %name Filesystem

%files
%{_bindir}/qdirstat
%{_bindir}/qdirstat-cache-writer
%{_datadir}/applications/qdirstat.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/qdirstat.svg
%license %{_docdir}/qdirstat/LICENSE
%doc README.md doc/cache-file-format.txt doc/*.md
%dir %{_docdir}/%{name}/stats
%{_docdir}/%{name}/stats/*.md
%{_mandir}/man1/qdirstat.1.gz
%{_mandir}/man1/qdirstat-cache-writer.1.gz

%changelog
* Sun Jan 14 2024 Stefan Hundhammer <shundhammer@suse.com>
- Update to V1.9:
  - Greatly improved the visual appearance of the treemap
  - Dominant items are now highlighted in bold font in the tree view
  - New "Find" function in the scanned directory tree
  - Added support for bookmarks
  - New documentation to explain the treemap
  - Some small improvements
  - Bug fixes
* Thu Jun 30 2022 Stefan Hundhammer <shundhammer@suse.com>
- Update to V1.8.1:
  - New treemap interaction: Middle click to show parent hierarchy
  - Some small improvements
  - Bug fixes
* Sat Aug 28 2021 Stefan Hundhammer <shundhammer@suse.com>
- Update to V1.8:
  - New view: File Age Statistics
  - Navigation history like in a web browser (Back, Forward)
  - Bug fixes
  - Some small improvements
* Mon Apr  5 2021 Stefan Hundhammer <shundhammer@suse.com>
- Update to V1.7.1:
  - New "Discover" actions to easily find
  - the largest files
  - the newest files
  - the oldest files
  - files with multiple hard links
  - broken symbolic links
  - sparse files
  - Now showing the target of symbolic links in the details panel
  - Menu reorganization
  - Bug fixes
* Sun Jul 26 2020 Stefan Hundhammer <shundhammer@suse.com>
- Update to V1.7:
  - Closing the gap between sizes reported by QDirstat and sizes
    reported by the "du" command: Now also taking the allocated
    size into account
  - New "Mounted Filesystems" window showing output similar to "df"
  - New directory selection dialog showing all (real) filesystems
  - Workaround for NTFS oddities: Ignoring hard links on NTFS
  - Bug fixes
* Thu Feb 13 2020 Stefan Hundhammer <shundhammer@suse.com>
- Update to V1.6.1:
  - Improved handling for "permission denied" errors while reading
    directories
  - Show exact byte size on demand
  - New optional tree column "oldest file"
  - Bug fix: Fixed text color in histogram in dark widget themes
* Mon Jul 22 2019 shundhammer@suse.de
- Update to V1.6:
  - Packages view
  - Unpackaged files view
  - Performance improvements
  - Bug fixes
* Wed Nov  7 2018 shundhammer@suse.de
- Update to V1.5:
  - Breadcrumbs navigation
  - File details panel
  - Package manager support for rpm, dpkg, pacman
  - Switchable different main window layouts
  - Bug fixes
* Sun Jun  4 2017 shundhammer@suse.de
- Update to V1.4 (File size stats (histogram) and more)
* Sun Mar  5 2017 shundhammer@suse.de
- Update to V1.3 (File type stats window and more)
* Mon Jan  9 2017 shundhammer@suse.de
- Update to V1.2 (Improved Btrfs subvolume support)
* Sat Nov 12 2016 jengelh@inai.de
- Own hicolor, because BuildRequiring it does not fix the
  post-build situation.
* Mon Oct 31 2016 Stefan.Hundhammer@gmx.de
- Update to V1.1-Pumpkin
* Tue Jul 26 2016 sflees@suse.de
- Include the hicolor-icon-theme rather than trying to make its
  directories owned by this rpm
* Mon May 16 2016 Stefan.Hundhammer@gmx.de
- Initial stable release V1.0
